<?php

namespace Drupal\Tests\views_accordion_foundation\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Functional tests for the Views Accordion Foundation module.
 *
 * @group views_accordion_foundation
 */
class ViewsAccordionFoundationFunctionalTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'node',
    'views',
    'foundation_sites',
    'views_accordion_foundation',
    'views_accordion_foundation_test',
    'views_ui',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $user = $this->drupalCreateUser([
      'access administration pages',
      'administer views',
    ]);
    $this->drupalLogin($user);
  }

  /**
   * Tests Views Accordion functionality.
   */
  public function testViewsAccordion() {
    $session = $this->assertSession();
    // Test views add form.
    $edit = [
      'id' => 'test',
      'label' => 'test',
      'show[wizard_key]' => 'node',
      'show[sort]' => 'none',
      'page[create]' => 1,
      'page[title]' => 'Test',
      'page[path]' => 'test',
      'page[style][style_plugin]' => 'views_accordion',
      'page[style][row_plugin]' => 'teasers',
    ];
    $this->drupalGet('admin/structure/views/add');
    $session->statusCodeEquals(200);
    $this->submitForm($edit, 'Save and edit');
    $session->pageTextContains('Views accordion requires Fields as row style');

    $edit['page[style][row_plugin]'] = 'fields';
    $this->drupalGet('admin/structure/views/add');
    $session->statusCodeEquals(200);
    $this->submitForm($edit, 'Save and edit');
    $session->pageTextContains('The view test has been saved.');

    // Assert the options of our exported view display correctly.
    $this->drupalGet('admin/structure/views/view/views_accordion_test/edit');
    $session->statusCodeEquals(200);
    $session->pageTextContains('jQuery UI accordion');

    // Verify the style options show with the right values in the form.
    $this->drupalGet('admin/structure/views/nojs/display/views_accordion_test/page_1/style_options');
    $session->statusCodeEquals(200);
    $session->checkboxNotChecked('style_options[grouping][0][use-grouping-header]');
    $session->checkboxNotChecked('style_options[disableifone]');
    $session->checkboxNotChecked('style_options[collapsible]');
    $session->fieldValueEquals('style_options[animated]', 'none');
    $session->fieldValueEquals('style_options[animation_time]', '300');
    $session->fieldValueEquals('style_options[heightStyle]', 'auto');
    $session->fieldValueEquals('style_options[event]', 'click');
    $session->checkboxChecked('style_options[use_header_icons]');
    $session->fieldValueEquals('style_options[icon_header]', 'ui-icon-triangle-1-e');
    $session->fieldValueEquals('style_options[icon_active_header]', 'ui-icon-triangle-1-s');
  }

}
